%global srcname flufl.bounce
%global pkgname flufl-bounce
%global summary Email bounce detectors
%global _description \
The flufl.bounce library provides a set of heuristics and an API for         \
detecting the original bouncing email addresses from a bounce message.  Many \
formats found in the wild are supported, as are VERP and RFC 3464 (DSN).

# EPEL7 support: default Python is Python 2, and Python2 packages prefix
# is unversioned.
%if 0%{?rhel} && 0%{?rhel} <= 7
%global py2_namespace python
%else
%global py2_namespace python2
%endif

Name:           python-%{pkgname}
Version:        2.3
Release:        3%{?dist}
Summary:        %{summary}

License:        LGPLv3+
URL:            https://gitlab.com/warsaw/flufl.bounce
Source0:        https://files.pythonhosted.org/packages/source/f/%{srcname}/%{srcname}-%{version}.tar.gz
BuildArch:      noarch

BuildRequires:  %{py2_namespace}-devel
BuildRequires:  %{py2_namespace}-setuptools
BuildRequires:  %{py2_namespace}-zope-interface
BuildRequires:  python-enum34
# Python3
BuildRequires:  python3-pkgversion-macros
BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_pkgversion}-setuptools
BuildRequires:  python%{python3_pkgversion}-zope-interface
%if 0%{?with_python3_other}
BuildRequires:  python%{python3_other_pkgversion}-devel
BuildRequires:  python%{python3_other_pkgversion}-setuptools
BuildRequires:  python%{python3_other_pkgversion}-zope-interface
%endif

%description %{_description}


%if %{py2_namespace} != python
%package -n %{py2_namespace}-%{pkgname}
Summary:        %{summary}
%{?python_provide:%python_provide %{py2_namespace}-%{pkgname}}
Requires:       %{py2_namespace}-setuptools
Requires:       %{py2_namespace}-zope-interface
Requires:       python-enum34

%description -n %{py2_namespace}-%{pkgname} %{_description}
%endif


%package -n python%{python3_pkgversion}-%{pkgname}
Summary:        %{summary}
%{?python_provide:%python_provide python%{python3_pkgversion}-%{pkgname}}
Requires:       python%{python3_pkgversion}-setuptools
Requires:       python%{python3_pkgversion}-zope-interface

%description -n python%{python3_pkgversion}-%{pkgname} %{_description}


%if 0%{?with_python3_other}
%package -n python%{python3_other_pkgversion}-%{pkgname}
Summary:        %{summary}
%{?python_provide:%python_provide python%{python3_other_pkgversion}-%{pkgname}}
Requires:       python%{python3_other_pkgversion}-setuptools
Requires:       python%{python3_other_pkgversion}-zope-interface

%description -n python%{python3_other_pkgversion}-%{pkgname} %{_description}
%endif


%prep
%autosetup -n %{srcname}-%{version}


%build
%py2_build
%py3_build
%if 0%{?with_python3_other}
%py3_other_build
%endif


%install
%py2_install
%py3_install
%if 0%{?with_python3_other}
%py3_other_install
%endif

# This will go in %%doc
rm -rf %{buildroot}%{_prefix}/lib/python*/site-packages/flufl/bounce/{*.rst,docs,conf.py}


%check
%{__python2} setup.py test
%{__python3} setup.py test
%if 0%{?with_python3_other}
%{__python3_other} setup.py test
%endif


%files -n %{py2_namespace}-%{pkgname}
%license COPYING.LESSER
%doc flufl/bounce/README.rst flufl/bounce/NEWS.rst flufl/bounce/docs/using.rst
%{python2_sitelib}/flufl/
%{python2_sitelib}/%{srcname}-%{version}*-py%{python2_version}.egg-info/
%{python2_sitelib}/%{srcname}-%{version}*-py%{python2_version}-nspkg.pth

%files -n python%{python3_pkgversion}-%{pkgname}
%license COPYING.LESSER
%doc flufl/bounce/README.rst flufl/bounce/NEWS.rst flufl/bounce/docs/using.rst
%{python3_sitelib}/flufl/
%{python3_sitelib}/%{srcname}-%{version}*-py%{python3_version}.egg-info/
%{python3_sitelib}/%{srcname}-%{version}*-py%{python3_version}-nspkg.pth

%if 0%{?with_python3_other}
%files -n python%{python3_other_pkgversion}-%{pkgname}
%license COPYING.LESSER
%doc flufl/bounce/README.rst flufl/bounce/NEWS.rst flufl/bounce/docs/using.rst
%{python3_other_sitelib}/flufl/
%{python3_other_sitelib}/%{srcname}-%{version}*-py%{python3_other_version}.egg-info/
%{python3_other_sitelib}/%{srcname}-%{version}*-py%{python3_other_version}-nspkg.pth
%endif


%changelog
* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 2.3-2
- Rebuild for Python 3.6

* Wed Sep 14 2016 Aurelien Bompard <abompard@fedoraproject.org> - 2.3-1
- Initial package.
